#!/bin/sh

#Copyright (C) 2006 - 2008 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or
#Modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details

. /opt/hinemos/hinemos.cfg
                                                                                                     
# check for incorrect use
EXEC_USER=`/usr/bin/whoami`
if [ ${EXEC_USER} != "hinemos" ]; then
        echo "";
        echo "ERROR  Hinemos Maneger shutdown at incorrect user ";
        echo "";
        exit 1;
fi
                                                                                                     
if [ -f ${HINEMOS_LDAP_PID} ] ; then
    echo "waiting for slapd to stop..."
    kill -INT `cat ${HINEMOS_LDAP_PID}`
    echo "slapd stopped."
else
    echo "ldap_stop.sh : PID file \"${HINEMOS_LDAP_PID}\" does not exist"
    echo Is slapd running?
    exit 1
fi
